#!/usr/bin/env python3
# _*_ coding:utf-8 _*_
# SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
# SPDX-License-Identifier: GPL-2.0-only

"""
此配置文件用于标签化管理方案实现条件判断跳过的配置项；
在CSV文件中“跳过原因”列填入函数名和参数，即可实现条件判断跳过；
比如：
在CSV文件中“跳过原因”列填入：
    skipif_platform-aarch64
    函数名称为：skipif_platform，比如是此文件中定义了的函数；
    参数为：aarch64，多个参数用 & 符号连接；
    函数名与参数之间用 - （中横线）连接；
"""
import os

from setting.globalconfig import GlobalConfig


def skipif_platform(args: str):
    """平台跳过
    skipif_platform-aarch64
    """
    _skip_key = args.split("&")
    for key in _skip_key:
        if GlobalConfig.SYS_ARCH == key:
            return True
    return False


def skipif_xdg_type(args: str):
    """skipif wayland or x11
    skipif_xdg_type-wayland
    """
    _skip_key = args.split("&")
    for key in _skip_key:
        if GlobalConfig.DISPLAY_SERVER == key:
            return True
    return False


def skipif_cpu_name(args: str):
    """skipif cpu name
    使用 sudo dmidecode -s system-product-name 查看机器的cpu型号
    剔除中横线和&符号，比如：KLVV-W5821，标签记录为 KLVVW5821
    skipif_cpu_name-KLVVW5821
    """
    _skip_key = args.split("&")
    for key in _skip_key:
        if os.popen(
                f"echo '{GlobalConfig.PASSWORD}'| "
                "sudo -S dmidecode -s system-product-name | awk '{print $NF}'"
        ).read().strip("\n").replace("-", "").replace("&", "") == key:
            return True
    return False


def skipif_os_version(args: str):
    """
    系统版本跳过
    skipif_os_version-1060
    """
    _skip_key = args.split("&")
    for key in _skip_key:
        if key == GlobalConfig.OS_VERSION.get("MinorVersion"):
            return True
    return False



"""
    Python cFonts
    =============
    Sexy fonts for the console.

    :license: GNU GPLv2
    :author: Frost Ming<mianghong@gmail.com>
"""
import argparse
import json
import pkgutil
import random
import re
from typing import List, Mapping, Optional, Tuple

from .colors import pen
from .consts import ALIGNMENT, CHARS, SIZE, BgColors, CandyColors, Colors, FontFaces


class Font:
    colors: int
    lines: int
    buffer: List[str]
    letterspace: List[str]
    chars: Mapping[str, List[str]]

    def __init__(self, name: str) -> None:
        self.name = name
        if name == FontFaces.console.value:
            self.colors = 1
            self.lines = 1
            return
        metadata = pkgutil.get_data(__package__, "fonts/{}.json".format(name))
        assert metadata
        font_face = json.loads(metadata.decode("utf-8"))
        self.__dict__.update(font_face)

    def add_letter_spacing(self, output: List[str], letter_spacing: int) -> List[str]:
        lines = len(output) - self.lines
        for i in range(lines, len(output)):
            idx = i - lines
            space = self.letterspace[idx] or " "
            output[i] += space * letter_spacing
        return output

    def add_char(self, output: List[str], char: str) -> List[str]:
        lines = len(output) - self.lines
        for i in range(lines, len(output)):
            idx = i - lines
            output[i] += self.chars[char][idx]
        return output


def add_line(output: List[str], buffer: List[str], line_height: int) -> List[str]:
    """Add a new line to the output array.

    :param output: The output array the line shall be appended to
    :param buffer: An array of space we add at the beginning of each line
    :param line_height: The user defined line height

    :returns: The output array with new line
    """
    if not output:
        line_height = 0
    for _ in range(line_height):
        output.append("")
    output.extend(buffer)
    return output


def get_font(font: str) -> Font:
    """Get a selected JSON font-file object.

    :param font: The name of the font to be returned
    :returns: The font object of that file
    :raises: FileNotFoundError
    """
    return Font(font)


def clean_input(text: str, allowed_chars: str = CHARS) -> str:
    """Filter only allowed characters.

    :param text: The input text to be filtered
    :param allowed_chars: Allowed characters
    :returns: The filtered input text
    """
    return "".join(c for c in text if c.upper() in allowed_chars)


def char_length(character: List[str], letter_spacing: int = 0) -> int:
    """Return the max width of a character by looking at its longest line.

    :param character: The character array from the font face
    :param letter_spacing: The user defined letter spacing
    :returns: The length of a longest line in a character
    """
    stripped = [re.sub(r"(<([^>]+)>)", "", char) for char in character]
    char_width = max(map(len, stripped))

    if char_width == 0 and letter_spacing > 0:
        # Adding space to letter spacing
        char_width = 1
    return char_width


def align_text(
    output: List[str],
    line_length: int,
    character_lines: int,
    align: str,
    size: Tuple[int, int] = SIZE,
) -> List[str]:
    assert align in ALIGNMENT
    space = 0
    if align == "center":
        space = (size[0] - line_length) // 2
    elif align == "right":
        space = size[0] - line_length
    if space > 0:
        lines = len(output) - character_lines
        for i in range(lines, len(output)):
            output[i] = " " * space + output[i]
    return output


def colorize(line: str, font_colors: int, colors: List[str]) -> str:
    if font_colors > 1:
        for i in range(font_colors):
            try:
                color = colors[i]
            except IndexError:
                color = Colors.system.value
            if color == Colors.candy.value:
                color = random.choice(list(CandyColors)).value
            style = pen.style(color, False)
            line = line.replace("<c{}>".format(i + 1), style.open)
            line = line.replace("</c{}>".format(i + 1), style.close)
    elif font_colors == 1:
        try:
            color = colors[0]
        except IndexError:
            color = Colors.system.value
        if color == Colors.candy.value:
            color = random.choice(list(CandyColors)).value
        style = pen.style(color, False)
        line = style.open + re.sub(r"</?c\d+>", "", line) + style.close
    return line


def render_console(
    text: str,
    size: Tuple[int, int] = SIZE,
    colors: List[str] = [],
    align: str = "left",
    letter_spacing: Optional[int] = None,
    line_height: int = 1,
) -> List[str]:
    output: List[str] = []
    i = 0
    letter_spacing = max((letter_spacing or 1) - 1, 0)
    line_height = max(line_height - 1, 0)
    space = " " * letter_spacing
    LINE_BREAK_RE = re.compile(r"\r\n|\r|\n|\|")
    output_lines = [
        space.join(list(line)) for line in LINE_BREAK_RE.split(text.strip())
    ]

    while i < len(output_lines):
        line = output_lines[i]
        if len(line) > size[0]:
            output_lines[i : i + 1] = line[: size[0]].strip(), line[size[0] :].strip()
            line = output_lines[i]
        if len(colors) > 0 and colors[0] == Colors.candy.value:
            output.append("".join(colorize(c, 1, colors) for c in line))
        else:
            output.append(line)

        output = align_text(output, len(line), 1, align, size)
        output = add_line(output, [], line_height)

        i += 1

    return output


def _find_left_most_non_space(line: str) -> int:
    return min(i for i, c in enumerate(line) if c.strip() != "")


def _find_right_most_non_space(line: str) -> int:
    return max(i for i, c in enumerate(line) if c.strip() != "")


def paint_gradient(
    output: List[str],
    gradient: List[str],
    independent_gradient: bool,
    lines: int,
    font_lines: int,
    line_height: int,
    transition: bool,
) -> List[str]:
    """Apply gradient colors to output"""
    if independent_gradient:
        buffer: List[str] = []
        start = 0
        for _ in range(lines):
            temp = output[start : start + font_lines]
            add_line(
                buffer,
                paint_gradient(temp, gradient, False, 1, font_lines, 0, transition),
                line_height,
            )
            start += font_lines + line_height
        return buffer
    gradient = gradient or []
    output = [re.sub(r"</?c\d+>", "", line) for line in output]
    min_index = min(_find_left_most_non_space(line) for line in output if line.strip())
    max_index = max(_find_right_most_non_space(line) for line in output if line.strip())
    styles = pen.get_gradient(gradient, max_index - min_index + 1, transition)
    new_output: List[str] = []
    for line in output:
        if not line.strip():
            new_output.append(line)
            continue
        temp = list(line)
        for i, style in zip(range(min_index, max_index + 1), styles):
            if i >= len(temp) or not temp[i].strip():
                continue
            temp[i] = style.open + temp[i] + style.close
        new_output.append("".join(temp))
    return new_output


def render(
    text: str,
    font: str = FontFaces.block.value,
    size: Tuple[int, int] = SIZE,
    colors: Optional[List[str]] = None,
    background: str = BgColors.transparent.value,
    align: str = "left",
    letter_spacing: Optional[int] = None,
    line_height: int = 1,
    space: bool = True,
    max_length: int = 0,
    gradient: Optional[List[str]] = None,
    independent_gradient: bool = False,
    transition: bool = False,
    raw: bool = False,
) -> str:
    """Main function to get the colored output for a string.

    :param text: the string you want to render
    :param font: use to define the font
    :param size: a (width, height) tuple to define the window size
    :param colors: a list of color names to render sequentially
    :param background: background color name
    :param align: the alignment method: left/center/right
    :param letter_spacing: the amount of spacing inserted between letters
    :param line_height: the height of each line
    :param space: whether to wrap the output with blank lines
    :param max_length: define the max length of per line, use 0 to disable
    :param gradient: define the gradient color sequence
    :param independent_gradient: whether to apply gradient to each line independently
    :param transition: If set to True, will generate transition gradient colors
    :returns: the colored output string
    """
    font_face = get_font(font)
    colors = colors or []
    if colors and colors[0] != "system" and gradient:
        raise argparse.ArgumentError(
            None, "colors and gradient cannot be specified at the same time."
        )
    if font == FontFaces.console.value:
        # console fontface is pretty easy to process
        output = render_console(
            text,
            size=size,
            colors=colors,
            align=align,
            letter_spacing=letter_spacing,
            line_height=line_height,
        )
        lines = len(output)
    else:
        lines = 0
        if letter_spacing is None:
            letter_spacing = char_length(font_face.letterspace)
        line_length = char_length(font_face.buffer)
        max_chars = 0
        output = add_line([], font_face.buffer, line_height)
        lines += 1
        output = font_face.add_letter_spacing(output, letter_spacing)
        line_length += (
            char_length(font_face.letterspace, letter_spacing) * letter_spacing
        )
        text = clean_input(text)
        for c in text:
            c = c.upper()
            last_line_length = line_length

            if c != "|":
                line_length += char_length(font_face.chars[c], letter_spacing)
                line_length += (
                    char_length(font_face.letterspace, letter_spacing) * letter_spacing
                )

            if max_chars > max_length != 0 or c == "|" or line_length > size[0]:
                lines += 1
                output = align_text(
                    output, last_line_length, font_face.lines, align, size
                )

                line_length = char_length(font_face.buffer)
                line_length += (
                    char_length(font_face.letterspace, letter_spacing) * letter_spacing
                )
                if c != "|":
                    # if this is a character and not a line break
                    line_length += char_length(font_face.chars[c], letter_spacing)
                    line_length += (
                        char_length(font_face.letterspace, letter_spacing)
                        * letter_spacing
                    )
                max_chars = 0
                output = add_line(output, font_face.buffer, line_height)
                output = font_face.add_letter_spacing(output, letter_spacing)

            if c != "|":
                output = font_face.add_char(output, c)
                output = font_face.add_letter_spacing(output, letter_spacing)

        output = align_text(output, line_length, font_face.lines, align, size)
        if gradient:
            output = paint_gradient(
                output,
                gradient,
                independent_gradient,
                lines,
                font_face.lines,
                line_height,
                transition,
            )

    output = [colorize(line, font_face.colors, colors) for line in output]
    if space:
        # Blank lines at the beginning and end
        output = [""] * 2 + output + [""] * 2
    if background != BgColors.transparent.value:
        # Fill whitespaces to the full width.
        # See https://github.com/frostming/python-cfonts/issues/3
        output = [(line + " " * (size[0] - len(_strip_color(line)))) for line in output]
        style = pen.style(background, True)
        if output:
            output[0] = style.open + output[0]
            output[-1] += style.close
    if raw:
        # replace the escape character with the bytes for the escape character
        # \033 also works
        return repr("\n".join(output))[1:-1]
    else:
        return "\n".join(output)


def say(text: str, **options) -> None:
    """Render and write the output to stout.

    :param text: the string you want to render
    :param options: options passed as same as :func:`cfonts.render`
    :returns: None
    """
    write = render(text, **options)
    if write:
        print(write)


def _strip_color(text: str) -> str:
    regex = re.compile(r"\x1b\[\d+?m")
    return regex.sub("", text)



# _*_ coding:utf-8 _*_

# SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.

# SPDX-License-Identifier: GPL-2.0-only
# pylint: disable=C0114,C0203
import weakref
import threading


class Singleton(type):
    """底层单例模式封装"""

    _instance_lock = threading.Lock()

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        Singleton.__instance = None
        # 初始化存放实例地址
        self._cache = weakref.WeakValueDictionary()

    def __call__(self, *args, **kwargs):
        # 提取类初始化时的参数
        kargs = "".join([f"{key}" for key in args]) if args else ""
        kkwargs = "".join([f"{key}" for key in kwargs]) if kwargs else ""
        # 判断相同参数的实例师否被创建
        if kargs + kkwargs not in self._cache:  # 存在则从内存地址中取实例
            with Singleton._instance_lock:
                Singleton.__instance = super().__call__(*args, **kwargs)
                self._cache[kargs + kkwargs] = Singleton.__instance
        # 不存在则新建实例
        else:
            Singleton.__instance = self._cache[kargs + kkwargs]
        return Singleton.__instance



#!/usr/bin/env python3
# _*_ coding:utf-8 _*_

# SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.

# SPDX-License-Identifier: GPL-2.0-only
# pylint: disable=C0114
# pylint: disable=E0401,C0413,R0903,W0707,W0611
try:
    import cv2 as cv

    GET_OPENCV_FORM_RPC = False
except ModuleNotFoundError:
    GET_OPENCV_FORM_RPC = True

from image_center import ImageCenter
from image_center.conf import setting as image_setting

from setting import conf

image_setting.PORT = conf.OPENCV_PORT
image_setting.SERVER_IP = conf.OPENCV_SERVER_HOST
image_setting.NETWORK_RETRY = int(conf.OPENCV_NETWORK_RETRY)
image_setting.PAUSE = float(conf.OPENCV_PAUSE)
image_setting.TIMEOUT = float(conf.OPENCV_TIMEOUT)
image_setting.MAX_MATCH_NUMBER = int(conf.OPENCV_MAX_MATCH_NUMBER)


class ImageUtils(ImageCenter):
    """图像识别的工具类"""



# -*- coding: utf-8 -*-
from __future__ import absolute_import, division, print_function, unicode_literals
"""Utility functions for 'dumping' trees of Node objects.

Author: Zack Cerza <zcerza@redhat.com>, Matěj Cepl <mcepl@redhat.com>"""
from io import StringIO

spacer = u' '


def dump_str(node):
    with StringIO as tmp_file:
        plain(node, output=tmp_file)
        dump_str = tmp_file.getvalue()
        return dump_str


def plain(node, output=None):
    """
    Plain-text dump. The hierarchy is represented through indentation.
    """
    close_output = False

    def crawl(node, depth):
        do_dump(node, depth)
        actions_keys = list(node.actions.keys())
        actions_keys.sort()
        for action in actions_keys:
            do_dump(node.actions[action], depth + 1)
        for child in node.children:
            crawl(child, depth + 1)

    def dumpFile(item, depth):
        _file.write(str(spacer * depth) + str(item) + str('\n'))

    def dumpStdOut(item, depth):
        try:
            print(spacer * depth + str(item))  # py3
        except UnicodeDecodeError:
            print(spacer * depth + str(item).decode('utf8'))  # py2 fallback

    _file = None

    if output:
        do_dump = dumpFile
        try:
            if hasattr(output, 'write'):
                _file = output
            elif isinstance(output, basestring):  # py2
                _file = open(output, 'w')
                close_output = True
        except NameError:
            if isinstance(output, str):  # there's no basestring in py3 (no str and unicode)
                _file = open(output, 'w')
                close_output = True
    else:
        do_dump = dumpStdOut

    crawl(node, 0)

    if close_output:
        _file.close()



#!/usr/bin/env python3
# _*_ coding:utf-8 _*_

# SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.

# SPDX-License-Identifier: GPL-2.0-only
import os

from setting.globalconfig import GlobalConfig
# wayland PATH
if GlobalConfig.IS_WAYLAND:
    os.environ["QT_WAYLAND_SHELL_INTEGRATION"] = "kwayland-shell"
    os.environ["XDG_SESSION_DESKTOP"] = "Wayland"
    os.environ["XDG_SESSION_TYPE"] = "wayland"
    os.environ["WAYLAND_DISPLAY"] = "wayland-0"
    os.environ["GDMSESSION"] = "Wayland"
    os.environ["DBUS_SESSION_BUS_ADDRESS"] = "unix:path=/run/user/1000/bus"

from platform import machine
import ctypes


class Geometry(ctypes.Structure):
    """sub structure"""
    _fields_ = [
        ("x", ctypes.c_int),
        ("y", ctypes.c_int),
        ("width", ctypes.c_int),
        ("height", ctypes.c_int),
    ]


class WindowStructure(ctypes.Structure):
    """window structure"""
    _fields_ = [
        ("pid", ctypes.c_int),
        ("windowId", ctypes.c_int),
        ("resourceName", ctypes.c_char * 256),
        ("Geometry", Geometry),
        ("isMinimized", ctypes.c_bool),
        ("isFullScreen", ctypes.c_bool),
        ("isActive", ctypes.c_bool),
    ]


class WaylandWindowInfo:
    """获取窗口信息"""

    def __init__(self):
        self.library = ctypes.cdll.LoadLibrary(f"/usr/lib/{machine()}-linux-gnu/libdtkwmjack.so")
        self.library.InitDtkWmDisplay()

    def window_id(self):
        """窗口id"""
        self.library.GetWindowFromPoint.restype = ctypes.c_int
        wid = self.library.GetWindowFromPoint()
        return wid

    def window_info(self):
        """窗口信息"""
        wid = self.window_id()
        self.library.GetWindowState.restype = ctypes.POINTER(WindowStructure)
        ws = self.library.GetWindowState(wid)
        window_info = ws.contents.Geometry
        resourceName = ws.contents.resourceName.decode("utf-8")
        if not resourceName:
            resourceName = os.popen(f"cat /proc/{ws.contents.pid}/cmdline").read().strip()
        return {
            "name": resourceName,
            "wininfo": (
                window_info.x,
                window_info.y,
                window_info.width,
                window_info.height
            ),
        }

if __name__ == '__main__':
    WaylandWindowInfo().window_info()


#!/usr/bin/env python3
# _*_ coding:utf-8 _*_

# SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.

# SPDX-License-Identifier: GPL-2.0-only
# pylint: disable=C0114,E1101
try:
    import cv2
except ModuleNotFoundError:
    pass


class VideoUtils:
    """
    获取视频属性的方法
    """

    @staticmethod
    def video_fps(path):
        """
         视频的帧率
        :param path: 视频路径
        :return:
        """
        cap = cv2.VideoCapture(path)
        return cap.get(cv2.CAP_PROP_FPS)

    @staticmethod
    def resolution(path):
        """
         视频的分辨率
        :param path: 视频路径
        :return:
        """
        cap = cv2.VideoCapture(path)
        width = cap.get(cv2.CAP_PROP_FRAME_WIDTH)
        height = cap.get(cv2.CAP_PROP_FRAME_HEIGHT)
        return width, height

    @staticmethod
    def video_time(path):
        """
         视频的时长
        :param path: 视频路径
        :return:
        """
        cap = cv2.VideoCapture(path)
        fps_ = cap.get(cv2.CAP_PROP_FPS)
        frame_number = cap.get(cv2.CAP_PROP_FRAME_COUNT)
        return frame_number / fps_



#!/usr/bin/env python3
# _*_ coding:utf-8 _*_

# SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.

# SPDX-License-Identifier: GPL-2.0-only
# pylint: disable=C0114
import json
import os
from os import makedirs
from os.path import exists
from re import findall, sub

from setting.globalconfig import GlobalConfig
from src import logger
from src.requestx import RequestX

MAX_CASE_NUMBER = 10000
# pylint: disable=unnecessary-lambda-assignment,R0903
runs_id_cmd_log = lambda x: sub(r"'run_case_id': '\d+', ", "", str(x))


class _Base:
    __author__ = "huangmingqiang@uniontech.com"

    def __init__(self, user=None, password=None):
        login_url = "https://pms.uniontech.com/user-login-Lw==.html"
        headers = {"content-type": "application/x-www-form-urlencoded; charset=UTF-8"}
        data = {
            "account": user if user else GlobalConfig.PMS_USER,
            "password": password if password else GlobalConfig.PMS_PASSWORD,
            "passwordStrength": "1",
            "referer": "/zentao/",
            "verifyRand": "370729017",
            "keepLogin": "0",
        }
        # pylint: disable=invalid-name
        self.rx = RequestX(login_url=login_url, headers=headers, data=data)


def _unicode_to_cn(in_str):
    """
    修改数据并进行编码解码操作，以完成u码转中文
    :param in_str: 字符串
    :return:/
    """
    local_in_str_replace = (
        in_str.replace(r"\"", '"')
            .replace(r"\/", "/")
            .replace(r"\\u", r"\u")
            .replace(r"\\n", "")
            .replace(r"\\r", "")
    )
    if isinstance(local_in_str_replace, bytes):
        local_temp = str(local_in_str_replace, encoding="utf-8")
        local_out = local_temp.encode("utf-8").decode("unicode_escape")
    else:
        local_out = local_in_str_replace.encode("utf-8").decode("unicode_escape")
    return (
        local_out.replace('"data":"{', '"data":{')
            .replace('","md5"', ',"md5"')
            .replace(":null", ':"null"')
            .replace(":true", ':"true"')
            .replace(":false", ':"false"')
    )


def write_case_result(item, report):
    """写用例执行的结果"""
    case_result_tpl = {
        "at_case_id": None,
        "case_id": None,
        "from_case_id": None,
        "task_id": None,
        "run_case_id": None,
        "result": None,
    }
    try:
        at_case_id = findall(r"test_.*?_(\d+)", item.name)[0]
    except IndexError:
        return
    taskid = item.config.option.task_id
    suiteid = item.config.option.suite_id
    caseid = None
    run_case_id = None
    from_case_id = None
    for mark in item.own_markers:
        if mark.args == ("PMS用例ID",):
            caseid = mark.name
        elif mark.args == ("run_case_id",):
            run_case_id = mark.name
        elif mark.args == ("from_case_id",):
            from_case_id = mark.name

    if None in (caseid, run_case_id):
        logger.error(f"{item.name},case_id 或 run_case_id 没获取到")

    case_result_tpl["run_case_id"] = run_case_id
    case_result_tpl["case_id"] = caseid
    case_result_tpl["from_case_id"] = from_case_id
    case_result_tpl["task_id"] = taskid or suiteid
    case_result_tpl["at_case_id"] = at_case_id
    case_result_tpl["item"] = item.name
    case_result_tpl["result"] = "pass" if report.outcome == "passed" else "fail"
    case_res_path = item.session.case_res_path
    if not exists(case_res_path):
        makedirs(case_res_path)

    json_file_name = f"{os.path.splitext(item.fspath.basename)[0]}.json"
    abs_json_file_path = f"{case_res_path}/{json_file_name}"
    if exists(abs_json_file_path):
        with open(abs_json_file_path, "r", encoding="utf-8") as _f:
            case_res_from_json = json.load(_f)

        if item.execution_count >= 2:
            if (
                    case_res_from_json.get("result") == "fail"
                    and case_result_tpl["result"] == "pass"
                    and case_res_from_json.get("item") == case_result_tpl["item"]
            ):
                case_result_tpl["result"] = "cover-pass"
                with open(abs_json_file_path, "w+", encoding="utf-8") as _f:
                    _f.write(json.dumps(case_result_tpl, indent=2, ensure_ascii=False))
        else:
            if case_res_from_json.get("result") in ("pass", "cover-pass") and case_result_tpl["result"] == "fail":
                with open(abs_json_file_path, "w+", encoding="utf-8") as _f:
                    _f.write(json.dumps(case_result_tpl, indent=2, ensure_ascii=False))
    else:
        with open(abs_json_file_path, "w+", encoding="utf-8") as _f:
            _f.write(json.dumps(case_result_tpl, indent=2, ensure_ascii=False))



#!/usr/bin/env python3
# _*_ coding:utf-8 _*_

# SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.

# SPDX-License-Identifier: GPL-2.0-only
# pylint: disable=C0114
# pylint: disable=W0707,W0611
try:
    from image_center import TemplateElementNotFound
    from image_center import TemplatePictureNotExist
except ImportError:
    raise ModuleNotFoundError

from src import logger


class ApplicationStartError(BaseException):
    """
    应用程序未启动
    """

    def __init__(self, result):
        """
        应用程序未启动
        :param result: 结果
        """
        err = f"应用程序未启动,{result}"
        logger.error(err)
        BaseException.__init__(self, err)


class ApplicationError(BaseException):
    """应用程序错误"""

    def __init__(self, msg):
        """
        应用程序错误
        :param msg: 结果
        """
        logger.error(msg)
        BaseException.__init__(self, msg)


class ElementNotFound(BaseException):
    """未找到元素"""

    def __init__(self, name):
        """
        未找到元素
        :param name: 命令
        """
        err = f"====未找到“{name}”元素！===="
        logger.error(err)
        BaseException.__init__(self, err)


# class TemplateElementNotFound(BaseException):
#     """通过模板资源未匹配到对应元素"""
#
#     def __init__(self, *name):
#         """
#         通过模板资源未匹配到对应元素
#         :param name: 命令
#         """
#         err = "通过图片资源, 未在屏幕上匹配到元素"
#         template = [f"{i}.png" for i in name]
#         BaseException.__init__(self, err, *template)


class TemplateElementFound(BaseException):
    """通过模板资源匹配到对应元素"""

    def __init__(self, *name):
        """
        通过模板资源匹配到对应元素
        :param name: 命令
        """
        err = "通过图片资源, 在屏幕中匹配到了不应该出现的元素"
        template = [f"{i}.png" for i in name]
        BaseException.__init__(self, err, *template)


# class TemplatePictureNotExist(BaseException):
#     """图片资源，文件不存在"""
#
#     def __init__(self, name):
#         """
#         文件不存在
#         :param name: 命令
#         """
#         err = f"图片资源：{name} 文件不存在!"
#         logger.error(err)
#         BaseException.__init__(self, err)


class AssertOptionError(AssertionError):
    """断言操作失败"""

    def __init__(self, e):
        """
        断言操作失败
        """
        err = f"断言操作失败，未知原因：{e}"
        logger.error(err)
        AssertionError.__init__(self, err)


class ParamError(BaseException):
    """参数错误"""

    def __init__(self, name, msg):
        """
        参数错误
        :param name: 命令
        """
        err = f"参数错误：{name}、\n{msg}"
        logger.error(err)
        BaseException.__init__(self, err)


class NoIconOfThisSize(BaseException):
    """没有操作的选项"""

    def __init__(self, size):
        """
        参数错误
        :param size:
        """
        err = f"参数错误：{size}"
        logger.error(err)
        BaseException.__init__(self, err)


class NoSuchWindowPositionParameter(BaseException):
    """没有此窗口位置参数"""

    def __init__(self, size):
        """
        参数错误
        :param size:
        """
        err = f"参数错误：{size}, 没有此窗口位置参数"
        logger.error(err)
        BaseException.__init__(self, err)


class GetWindowInformation(BaseException):
    """获取窗口信息错误"""

    def __init__(self, msg):
        """
        获取窗口信息错误
        """
        logger.error(msg)
        BaseException.__init__(self, msg)


class NoSetReferencePoint(BaseException):
    """没有设置参考点"""

    def __init__(self, msg):
        err = f"没有设置参考点！| {msg}"
        logger.error(err)
        BaseException.__init__(self, err)


class ShellExecutionFailed(BaseException):
    """shell执行失败"""

    def __init__(self, msg):
        err = f"shell执行失败！| {msg}"
        logger.error(err)
        BaseException.__init__(self, err)


class ElementExpressionError(BaseException):
    """查找元素表达式错误"""

    def __init__(self, msg):
        err = f"查找元素表达式错误 <{msg}>"
        logger.error(err)
        BaseException.__init__(self, err)


class NoSuchSkipMethodFound(BaseException):
    """未找到判断是否跳过的自定义方法"""

    def __init__(self, msg):
        err = f"未找到判断是否跳过的自定义方法 <{msg}>"
        logger.error(err)
        BaseException.__init__(self, err)


class OcrTextRecognitionError(BaseException):
    """Ocr文字识别失败"""

    def __init__(self, msg):
        err = f"Ocr文字识别失败 <{msg}>"
        logger.error(err)
        BaseException.__init__(self, err)
